==> psxc-imdb_v2.2.tgz: psxc-imdb_v2.2/psxc-imdb-bot.tcl <==
#######################
# PSXC-IMDB bot-addon #
# -------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.

###################
##### config ######

# relative path and name of the config.
# make sure you edit the conf-file before starting the bot.
set psxcbotconf "scripts/psxc-imdb-conf.tcl"

#
##### config done #####
#######################

catch {
  source "${psxcbotconf}"
}

proc readimdb {} {
 global psxc psxclog
 utimer 5 "readimdb"
 set psxclogsize [file size $psxc(IMDBLOG)]
 if { $psxclogsize == $psxclog } { return 0 }
 if { $psxclogsize  < $psxclog } { set psxclog 0 }
 set psxcascript $psxc(IMDBSCRIPT)
 set psxcaout [ exec $psxcascript &]
# set psxclog [file size $psxc(IMDBLOG)]
 return 0
}

proc showimdb {} {
 global psxc psxclog psxcmovie
 utimer 5 "showimdb"
 set psxcmoviesize [file size $psxc(IMDBMOVIE)]
 if { $psxcmoviesize == $psxcmovie } { return 0 }
 if { $psxcmoviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set psxcoffset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $psxcoffset $psxcmovie
 while {![eof $psxcoffset]} {
  set psxcline [gets $psxcoffset]
  if {$psxcline == ""} {continue}
  set psxcthr [lindex $psxcline 7]
  foreach psxcimdbchan $psxc(IMDBCHANNEL) { putserv "PRIVMSG $psxcimdbchan :$psxc(IMDBTRIG) $psxcthr" }
 }
 close $psxcoffset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}

proc preimdb {} {
 global psxc psxcprelog
 utimer 5 "preimdb"
 set psxcpresize [file size $psxc(PRELOG)]
 if { $psxcpresize == $psxcprelog } { return 0 }
 if { $psxcpresize  < $psxcprelog } { set psxcprelog 0 }
 set psxccscript $psxc(PRESCRIPT)
 set psxccout [ exec $psxccscript &]
 set psxcprelog [file size $psxc(PRELOG)]
 return 0
}

set psxclog 0
set psxcprelog 0
set psxcmovie [file size $psxc(IMDBMOVIE)]

putlog "psxc-imdb: Loading bot-addon v2.0c..."

if { $psxc(USEBOT) == "YES" } {
 putlog "psxc-imdb: imdb-logging is ON."
 readimdb
 }
if { $psxc(USEFULL) == "YES" } {
 putlog "psxc-imdb: imdb-fullmode is ON."
 showimdb
 }
if { $psxc(USEPRE) == "YES" } {
 putlog "psxc-imdb: imdb-premode is ON."
 preimdb
 }

putlog "psxc-imdb: Ready."

==> psxc-imdb_v2.3.tgz: psxc-imdb_v2.3/psxc-imdb-bot.tcl <==
#######################
# PSXC-IMDB bot-addon #
# -------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.

###################
##### config ######

# relative path and name of the config.
# make sure you edit the conf-file before starting the bot.
set psxcbotconf "scripts/psxc-imdb-conf.tcl"

#
##### config done #####
#######################

catch {
  source "${psxcbotconf}"
}

proc readimdb {} {
 global psxc psxclog
 utimer 5 "readimdb"
 set psxclogsize [file size $psxc(IMDBLOG)]
 if { $psxclogsize == $psxclog } { return 0 }
 if { $psxclogsize  < $psxclog } { set psxclog 0 }
 set psxcascript $psxc(IMDBSCRIPT)
 set psxcaout [ exec $psxcascript &]
 return 0
}

proc showimdb {} {
 global psxc psxcmovie
 utimer 5 "showimdb"
 set psxcmoviesize [file size $psxc(IMDBMOVIE)]
 if { $psxcmoviesize == $psxcmovie } { return 0 }
 if { $psxcmoviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set psxcoffset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $psxcoffset $psxcmovie
 while {![eof $psxcoffset]} {
  set psxcline [gets $psxcoffset]
  if {$psxcline == ""} {continue}
  set psxcthr [lindex $psxcline 7]
  foreach psxcimdbchan $psxc(IMDBCHANNEL) { putserv "PRIVMSG $psxcimdbchan :$psxc(IMDBTRIG) $psxcthr" }
 }
 close $psxcoffset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}

proc preimdb {} {
 global psxc psxcprelog
 utimer 5 "preimdb"
 set psxcpresize [file size $psxc(PRELOG)]
 if { $psxcpresize == $psxcprelog } { return 0 }
 if { $psxcpresize  < $psxcprelog } { set psxcprelog 0 }
 set psxccscript $psxc(PRESCRIPT)
 set psxccout [ exec $psxccscript &]
 set psxcprelog [file size $psxc(PRELOG)]
 return 0
}

proc psxc-imdbsearch {nick uhost hand chan args} {
   putserv "PRIVMSG $chan :\002IMDB :\002 Looking up iMDB info.."
   catch {exec /glftpd/bin/psxc-imdb-find.sh $args} psxcimdbfindlog
   if { $psxcimdbfindlog == "child process exited abnormally" } { putserv "privmsg $chan :error..." ; return }
   putserv "PRIVMSG $chan :[lrange $psxcimdbfindlog 0 end]"
}

putlog "psxc-imdb: Loading bot-addon v2.3..."

if { $psxc(USEBOT) == "YES" } {
 set psxclog 0
 putlog "psxc-imdb: imdb-logging is ON."
 readimdb
 }
if { $psxc(USEFULL) == "YES" } {
 putlog "psxc-imdb: imdb-fullmode is ON."
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 showimdb
 }
if { $psxc(USEPRE) == "YES" } {
 putlog "psxc-imdb: imdb-premode is ON."
 set psxcprelog 0
 preimdb
 }

if { $psxc(USEFIND) == "YES" } {
 putlog "psxc-imdb: !imdb-mode is ON."
 bind pub -|- $psxc(FINDTRIG) psxc-imdbsearch
 }

putlog "psxc-imdb: Ready."
